Crate ewe_temple

Crate ewe_temple 

Structs

Directorate
PackageConfig
PackageConfig defines underlying default configuration that the PackageGenerator will use in it’s underlying behavior of outputing the final package out.
PackageGenerator
RustConfig
RustProjectConfigurator
StringIterator
Templater

Enums

FileContent
FileSystemCommand
PackageGenError
RustProjectConfiguratorError

Traits

PackageConfigurator
PackageConfigurator defines the underlying expectation the PackageGenerator expects when it receives a target configuration like the target output directory, custom parameters to apply to generated files in cases of templates and what target template name representing the Project template to be used in pacakge generation.
PackageDirectorate

Type Aliases

PackageGenResult
RustProjectConfiguratorResult