Structs
- Directorate
- Package
Config - PackageConfig defines underlying default configuration that the PackageGenerator will use in it’s underlying behavior of outputing the final package out.
- Package
Generator - Rust
Config - Rust
Project Configurator - String
Iterator - Templater
Enums
Traits
- Package
Configurator - PackageConfigurator defines the underlying expectation the PackageGenerator expects when it receives a target configuration like the target output directory, custom parameters to apply to generated files in cases of templates and what target template name representing the Project template to be used in pacakge generation.
- Package
Directorate